@@ -28,6 +28,10 @@ class BOMItemAdmin(admin.ModelAdmin):
 class CBOMItemInline(admin.TabularInline):
     model = models.CBOMItem
 
+    def get_queryset(self, request):
+        return models.CBOMItem.objects.all().select_related(
+            'bom', 'epn', 'unit')
+
 
 class CBOMAdmin(admin.ModelAdmin):
     list_display = ['customer', 'description', 'html_link', 'product',
@@ -39,6 +43,7 @@ class CBOMAdmin(admin.ModelAdmin):
 class CBOMItemAdmin(admin.ModelAdmin):
     list_display = ['bom', 'epn', 'qty', 'unit', 'position']
     search_fields = ['bom__description', 'bom__product', 'epn']
+    fields = ['bom', 'consign', 'epn', 'position', 'qty', 'unit']
 
 
 class CompanyAdmin(admin.ModelAdmin):
