@@ -80,6 +80,9 @@ class BOM(models.Model):
             ipn_code = None
         return u'BOM "{0}" for {1}'.format(trunc(self.description), ipn_code)
 
+    class Meta:
+        ordering = ('ipn__code', )
+
 
 class BOMItemManager(models.Manager):
     def get_queryset(self):
